Compliance_Essentials

Roles and Permissions

Compliance Essentials uses Splunk permissions and app-managed boundary permissions.

System Boundary Permissions

System boundaries can have admin permissions assigned to users or roles. Boundary admin access controls sensitive actions such as deleting a system boundary.

Current User

Several workflows use the current Splunk user to record ownership or activity, including: